
BASE_PATH: str = '/robinhood_data/'
LOG_DIR: str = f'{BASE_PATH}output/logs/'
TMP_DIR = f'{BASE_PATH}tmp/'

STOCKS_FILE_PATH: str = f'{TMP_DIR}stocks.json'

MAIN_EMAIL: str = 'mhowell234@gmail.com'
USERS_KEY: str = 'users'
DEFAULT_DELIMITER: str = ':'

TESTING: bool = True
DEBUG: bool = False
F_IT_MODE: bool = False
PROFILE_INFO: bool = False

RANDOM_INVESTORS: int = 7
BUY_ONE_SELL_ONE_MODE: bool = True




